@@ -165,7 +165,7 @@ class pan::TextMatch::PcreInfo
 
    public:
 
-      PcreInfo (): re(0) { } 
+      PcreInfo (): re(nullptr) { }
 
 
 
@@ -188,7 +188,7 @@ class pan::TextMatch::PcreInfo
           else
             options = (GRegexCompileFlags)G_REGEX_CASELESS;
 
-          GError * err = 0;
+          GError * err = nullptr;
           re = g_regex_new (pattern.c_str(), options, (GRegexMatchFlags)0, &err);
           if (err) {
             Log::add_err_va (_("Can't use regular expression \"%s\": %s"), pattern.c_str(), err->message);
@@ -250,7 +250,7 @@ namespace
       const guchar first_lc = tolower(*pat);
       const guchar * t = text;
       const guchar * text_end = text + text_len - pat_len + 1;
-      const guchar * pat_end = pat + pat_len; 
+      const guchar * pat_end = pat + pat_len;
       const guchar * p;
       const guchar * q;
 
@@ -294,7 +294,7 @@ namespace
       const guchar first = *pat;
       const guchar * t = text;
       const guchar * text_end = text + text_len - pat_len + 1;
-      const guchar * pat_end  = pat + pat_len; 
+      const guchar * pat_end  = pat + pat_len;
       const guchar * p;
       const guchar * q;
 
@@ -324,7 +324,7 @@ namespace
 
 /*****
 ******
-******  
+******
 ******
 *****/
 
@@ -383,14 +383,14 @@ TextMatch :: test (const StringView& text_in) const
 
 /*****
 ******
-******  
+******
 ******
 *****/
 
 TextMatch :: TextMatch ():
    _impl_text (),
    _skip (new char [UCHAR_MAX+1]),
-   _pcre_info (0),
+   _pcre_info (nullptr),
    _pcre_state (NEED_COMPILE)
 {
 }
@@ -410,7 +410,7 @@ TextMatch :: clear ()
   if (_pcre_state == COMPILED)
   {
     delete _pcre_info;
-    _pcre_info = 0;
+    _pcre_info = nullptr;
     _pcre_state = NEED_COMPILE;
   }
 }
@@ -497,12 +497,15 @@ TextMatch :: validate_regex (const char * text)
 
 TextMatch :: TextMatch (const TextMatch& that):
   _skip (new char [UCHAR_MAX+1]),
-  _pcre_info (0),
+  _pcre_info (nullptr),
   _pcre_state (NEED_COMPILE)
 {
   set (that.state);
 }
 
+//FIXME this is clearly doing something odd, but the solution of deleting the
+//assignment and writing defaulted move constructors/assignments won't work
+//till C++20
 TextMatch&
 TextMatch :: operator= (const TextMatch& that)
 {
