@@ -34,6 +34,8 @@
 #include "pad.h"
 #include "tango-colors.h"
 
+#include <pan/general/null.h>
+
 using namespace pan;
 
 namespace
@@ -48,19 +50,22 @@ namespace
   {
     public:
       Quark groupname;
-      unsigned long unread;
+      Article_Count unread;
 
     public:
-      virtual void get_value (int column, GValue* setme) {
+      void get_value (int column, GValue* setme) override {
         switch (column) {
-          case COL_UNREAD: set_value_ulong (setme, unread); break;
+          //
+          //FIXME Really?
+          //
+          case COL_UNREAD: set_value_ulong (setme, static_cast<uint64_t>(unread)); break;
         }
       }
   };
 
-  Quark * virtual_title_quark (0);
-  Quark * sub_title_quark (0);
-  Quark * other_title_quark (0);
+  Quark * virtual_title_quark (nullptr);
+  Quark * sub_title_quark (nullptr);
+  Quark * other_title_quark (nullptr);
 
   bool is_group (const Quark& name) {
     return !name.empty() &&
@@ -131,7 +136,7 @@ GroupPane :: get_full_selection () const
   quarks_v groups;
 
   // get a list of paths
-  GtkTreeModel * model (0);
+  GtkTreeModel * model (nullptr);
   GtkTreeSelection * selection (gtk_tree_view_get_selection (GTK_TREE_VIEW(_tree_view)));
   GList * list (gtk_tree_selection_get_selected_rows (selection, &model));
 
@@ -154,9 +159,7 @@ GroupPane ::  do_popup_menu (GtkWidget*, GdkEventButton *event, gpointer pane_g)
 {
   GroupPane * self (static_cast<GroupPane*>(pane_g));
   GtkWidget * menu (self->_action_manager.get_action_widget ("/group-pane-popup"));
-  gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,
-                  (event ? event->button : 0),
-                  (event ? event->time : 0));
+  gtk_menu_popup_at_pointer (GTK_MENU(menu),(GdkEvent*) event);
 }
 
 namespace
@@ -302,7 +305,7 @@ namespace
     MyRow tmp;
     tmp.groupname = groupname;
     rows_t::iterator it = _group_rows.find (&tmp);
-    return it==_group_rows.end() ? 0 : *it;
+    return it==_group_rows.end() ? nullptr : *it;
   }
 
   void
@@ -370,7 +373,7 @@ namespace
 		MyRow *rows(new MyRow [n]), *r(rows);
 		g_object_weak_ref (G_OBJECT(store), delete_rows, rows);
 
-		unsigned long unused;
+		Article_Count unused;
 		for (size_t i(0); i!=n; ++i, ++r)
 		{
 			r->groupname = folders_groupnames[i];
@@ -395,7 +398,7 @@ namespace
       MyRow *rows(new MyRow [n]), *r(rows);
       g_object_weak_ref (G_OBJECT(store), delete_rows, rows);
 
-      unsigned long unused;
+      Article_Count unused;
       for (size_t i(0); i!=n; ++i, ++r) {
         r->groupname = sub[i];
         data.get_group_counts (r->groupname, r->unread, unused);
@@ -420,7 +423,7 @@ namespace
       MyRow *rows(new MyRow[n]), *r(rows);
       g_object_weak_ref (G_OBJECT(store), delete_rows, rows);
 
-      unsigned long unused;
+      Article_Count unused;
       for (size_t i(0); i!=n; ++i, ++r) {
         r->groupname = unsub[i];
         data.get_group_counts (r->groupname, r->unread, unused);
@@ -434,7 +437,7 @@ namespace
       // or if there's no criteria and no subscribed groups (first-time usrs).
       // otherwise it's a flood of thousands of groups.
       // they can click the expander themselves to get that,
-      const bool user_did_search (match != 0);
+      const bool user_did_search (match != nullptr);
       if (!unsub.empty() && (user_did_search || sub.empty()))
         expandme.push_back (store->get_iter (row));
     }
@@ -489,7 +492,7 @@ GroupPane :: refresh_dirty_groups ()
     MyRow * row (find_row (*it));
     if (row)
     {
-      unsigned long unused;
+      Article_Count unused;
       _data.get_group_counts (row->groupname, row->unread, unused);
       _tree_store->row_changed (row);
     }
@@ -514,7 +517,7 @@ GroupPane :: on_group_read (const Quark& groupname)
        _dirty_groups_idle_tag = g_timeout_add (333, dirty_groups_idle, this);
 }
 void
-GroupPane :: on_group_counts (const Quark& groupname, unsigned long, unsigned long)
+GroupPane :: on_group_counts (const Quark& groupname, Article_Count, Article_Count)
 {
   on_group_read (groupname);
 }
@@ -559,7 +562,7 @@ GroupPane :: set_filter (const std::string& search_text, int mode)
   // pmatch will point to a local TextMatch matching on the filter-phrase,
   // or be a NULL pointer if the filter-phrase is empty
   TextMatch match;
-  TextMatch * pmatch (0);
+  TextMatch * pmatch (nullptr);
   if (!search_text.empty()) {
     if (mode == _GROUP)
       match.set (search_text, TextMatch::CONTAINS, false);
@@ -608,41 +611,10 @@ namespace
                                      GdkEventFocus * ,
                                      gpointer        )
   {
-#if !GTK_CHECK_VERSION(3,0,0)
-    gtk_widget_modify_text (w, GTK_STATE_NORMAL, NULL); // resets
-#else
-    gtk_widget_override_color(w, GTK_STATE_FLAG_NORMAL, NULL);
-#endif
     set_search_entry (w, search_text.c_str());
     return false;
   }
 
-  void refresh_search_entry (GtkWidget * w)
-  {
-    if (search_text.empty() && !gtk_widget_has_focus(w))
-    {
-#if !GTK_CHECK_VERSION(3,0,0)
-      GdkColor c;
-      c.pixel = 0;
-      c.red = c.green = c.blue = 0xAAAA;
-      gtk_widget_modify_text (w, GTK_STATE_NORMAL, &c);
-#else
-      GdkRGBA c;
-      gdk_rgba_parse (&c, "0xAAA");
-      gtk_widget_override_color(w, GTK_STATE_FLAG_NORMAL, &c);
-#endif
-      set_search_entry (w, _(mode_strings[mode]));
-    }
-  }
-
-  gboolean search_entry_focus_out_cb (GtkWidget     * w,
-                                      GdkEventFocus * ,
-                                      gpointer        )
-  {
-    refresh_search_entry (w);
-    return false;
-  }
-
   void search_activate (GroupPane * pane)
   {
     pane->set_filter (search_text, mode);
@@ -663,10 +635,10 @@ namespace
     remove_activate_soon_tag ();
   }
 
-  void entry_icon_released (GtkEntry*, GtkEntryIconPosition icon_pos, GdkEventButton *, gpointer menu)
+  void entry_icon_released (GtkEntry*, GtkEntryIconPosition icon_pos, GdkEventButton* event, gpointer menu)
   {
     if (icon_pos == GTK_ENTRY_ICON_PRIMARY)
-      gtk_menu_popup (GTK_MENU(menu), 0, 0, 0, 0, 0, gtk_get_current_event_time());
+      gtk_menu_popup_at_pointer (GTK_MENU(menu), (GdkEvent*) event);
   }
 
   void clear_button_clicked_cb (GtkEntry * e, GtkEntryIconPosition icon_pos, GdkEventButton *, gpointer pane_gpointer)
@@ -674,7 +646,6 @@ namespace
     if (icon_pos == GTK_ENTRY_ICON_SECONDARY)
     {
       set_search_entry (GTK_WIDGET(e), "");
-      refresh_search_entry (GTK_WIDGET(e));
       search_text.clear ();
       search_entry_activated (NULL, pane_gpointer);
     }
@@ -707,7 +678,6 @@ namespace
     if (gtk_check_menu_item_get_active  (menu_item))
     {
       mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(menu_item), "MODE"));
-      refresh_search_entry (GTK_WIDGET(entry_g));
       GroupPane * h = (GroupPane*) g_object_get_data (
                                              G_OBJECT(entry_g), "group-pane");
       bump_activate_soon_tag (h);
@@ -739,16 +709,16 @@ namespace
     GroupPane* pane (static_cast<GroupPane*>(gp));
     PanTreeStore * tree (PAN_TREE_STORE(model));
     MyRow * row (dynamic_cast<MyRow*>(tree->get_row (iter)));
-    const unsigned long& unread (row->unread);
+    const Article_Count & unread (row->unread);
     //const unsigned long& total (row->total);
     const Quark& name (row->groupname);
 
     const bool is_g (is_group(name));
     const bool do_shorten (shorten && is_g);
     std::string group_name (do_shorten ? get_short_name(StringView(name)) : name.to_string());
-    if (is_g && unread) {
+    if (is_g && static_cast<uint64_t>(unread) != 0) {
       char buf[64];
-      g_snprintf (buf, sizeof(buf), " (%lu)", unread);
+      g_snprintf (buf, sizeof(buf), " (%llu)", static_cast<uint64_t>(unread));
       group_name += buf;
     }
 
@@ -765,7 +735,7 @@ namespace
         bg_col = def_bg;
 
     g_object_set (renderer, "text", group_name.c_str(),
-                            "weight", (!is_g || unread ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL),
+                            "weight", (!is_g || static_cast<uint64_t>(unread) != 0 ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL),
                             "foreground", fg_col.empty() ? NULL : fg_col.c_str(),
                             "background", bg_col.empty() ? NULL : bg_col.c_str(),
                             NULL);
@@ -796,10 +766,10 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
 
   // find how many subscribed groups the tree's got
   GtkTreeIter sub_iter, virtual_iter;
-  gtk_tree_model_iter_nth_child (model, &sub_iter, 0, 1); // 'sub' node
+  gtk_tree_model_iter_nth_child (model, &sub_iter, nullptr, 1); // 'sub' node
   int n_groups = gtk_tree_model_iter_n_children (model, &sub_iter);
   if (n_groups < 1)
-    return 0;
+    return nullptr;
 
   // find the index of the current selection
   // (or -1 if no subscribed groups are selected)
@@ -824,17 +794,17 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
   {
     if (++n == n_groups) {
       if (start_pos == -1)
-        return 0;
+        return nullptr;
       n = 0;
     }
     if (n == start_pos)
-      return 0;
+      return nullptr;
 
     GtkTreeIter group_iter;
     gtk_tree_model_iter_nth_child (model, &group_iter, &sub_iter, n);
     const MyRow * row (dynamic_cast<MyRow*>(_tree_store->get_row (&group_iter)));
     const bool is_virtual (is_virtual_group(row->groupname));
-    if (!is_virtual && (row->unread || !unread_only))
+    if (!is_virtual && (static_cast<uint64_t>(row->unread) != 0 || !unread_only))
       return gtk_tree_model_get_path (model, &group_iter);
   }
 
@@ -922,16 +892,15 @@ GroupPane :: create_filter_entry ()
 {
   GtkWidget * entry = gtk_entry_new ();
   g_object_set_data (G_OBJECT(entry), "group-pane", this);
-  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                 GTK_ENTRY_ICON_SECONDARY,
-                                 GTK_STOCK_CLEAR );
-  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                 GTK_ENTRY_ICON_PRIMARY,
-                                 GTK_STOCK_FIND );
+  gtk_entry_set_icon_from_icon_name( GTK_ENTRY( entry ),
+                                     GTK_ENTRY_ICON_SECONDARY,
+                                     "edit-clear" );
+  gtk_entry_set_icon_from_icon_name( GTK_ENTRY( entry ),
+                                     GTK_ENTRY_ICON_PRIMARY,
+                                     "edit-find" );
 //  gtk_widget_set_size_request (entry, 133, -1);
   _action_manager.disable_accelerators_when_focused (entry);
   g_signal_connect (entry, "focus-in-event", G_CALLBACK(search_entry_focus_in_cb), NULL);
-  g_signal_connect (entry, "focus-out-event", G_CALLBACK(search_entry_focus_out_cb), NULL);
   g_signal_connect (entry, "activate", G_CALLBACK(search_entry_activated), this);
   g_signal_connect (entry, "icon-release", G_CALLBACK(clear_button_clicked_cb), this);
   entry_changed_tag = g_signal_connect (entry, "changed", G_CALLBACK(search_entry_changed_by_user), this);
@@ -942,7 +911,7 @@ GroupPane :: create_filter_entry ()
     mode = 1;
   else
     mode = 0;
-  GSList * l = 0;
+  GSList * l = nullptr;
   for (int i=0, qty=G_N_ELEMENTS(mode_strings); i<qty; ++i)
   {
     GtkWidget * w = gtk_radio_menu_item_new_with_label (l, _(mode_strings[i]));
@@ -956,7 +925,6 @@ GroupPane :: create_filter_entry ()
   }
   g_signal_connect (entry, "icon-release", G_CALLBACK(entry_icon_released), menu);
 
-  refresh_search_entry (entry);
   return entry;
 }
 
@@ -1006,7 +974,7 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs,
   _prefs (prefs),
   _group_prefs(group_prefs),
   _data (data),
-  _tree_view (0),
+  _tree_view (nullptr),
   _action_manager (action_manager),
   _dirty_groups_idle_tag (0)
 {
@@ -1033,13 +1001,13 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs,
 
   GtkTreeSelection * selection (gtk_tree_view_get_selection (GTK_TREE_VIEW(_tree_view)));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-  gtk_tree_selection_set_select_function (selection, select_func, 0, 0);
+  gtk_tree_selection_set_select_function (selection, select_func, nullptr, nullptr);
   g_signal_connect (selection, "changed", G_CALLBACK(on_selection_changed), this);
   on_selection_changed (selection, this);
 
 
-  g_signal_connect (_tree_view, "row_collapsed", G_CALLBACK(row_collapsed_or_expanded_cb), 0);
-  g_signal_connect (_tree_view, "row_expanded", G_CALLBACK(row_collapsed_or_expanded_cb), 0);
+  g_signal_connect (_tree_view, "row_collapsed", G_CALLBACK(row_collapsed_or_expanded_cb), nullptr);
+  g_signal_connect (_tree_view, "row_expanded", G_CALLBACK(row_collapsed_or_expanded_cb), nullptr);
   g_signal_connect (_tree_view, "button-press-event", G_CALLBACK(on_button_pressed), this);
   g_signal_connect (_tree_view, "button-release-event", G_CALLBACK(on_button_pressed), this);
   g_signal_connect (_tree_view, "popup-menu", G_CALLBACK(on_popup_menu), this);
@@ -1062,7 +1030,7 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs,
    gtk_tree_view_append_column (GTK_TREE_VIEW(_tree_view), col);
    gtk_tree_view_set_expander_column (GTK_TREE_VIEW(_tree_view), col);
    gtk_tree_view_column_pack_start (col, text_renderer, true);
-   gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_group_name, this, 0);
+   gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_group_name, this, nullptr);
 
   _root = scroll;
   _data.add_listener (this);
@@ -1088,8 +1056,11 @@ GroupPane :: ~GroupPane ()
 void
 GroupPane :: refresh_font ()
 {
+  // TODO: cleanup calls to gtk_widget_override_font. This requires
+  // changing font with CSS. This impact how to set preferences->Font
+  // item
   if (!_prefs.get_flag ("group-pane-font-enabled", false))
-    gtk_widget_override_font (_tree_view, 0);
+    gtk_widget_override_font (_tree_view, nullptr);
   else {
     const std::string str (_prefs.get_string ("group-pane-font", "Sans 10"));
     PangoFontDescription * pfd (pango_font_description_from_string (str.c_str()));
