@@ -17,6 +17,8 @@
  *
  */
 
+#include "log-ui.h"
+
 #include <config.h>
 #include <ostream>
 #include <fstream>
@@ -26,10 +28,11 @@
 #include <pan/general/log.h>
 #include <pan/general/macros.h>
 #include <pan/general/string-view.h>
-#include "log-ui.h"
 #include "pad.h"
 
-using namespace pan;
+#include <pan/general/null.h>
+
+namespace pan {
 
 namespace
 {
@@ -72,7 +75,7 @@ namespace
       }
     }
 
-    virtual void on_log_cleared () {
+    void on_log_cleared () override {
       gtk_tree_store_clear (myStore);
     }
   };
@@ -148,7 +151,7 @@ namespace
     const Log::entries_t& entries (Log::get().get_entries());
     foreach_const (Log::entries_t, entries, it) {
       GtkTreeIter   top, child, tmp;
-      gtk_tree_store_prepend (store, &top, 0);
+      gtk_tree_store_prepend (store, &top, nullptr);
       gtk_tree_store_set (store, &top,
                           COL_HIDDEN, "",
                           COL_SEVERITY, (it->severity & Log::PAN_SEVERITY_ERROR),
@@ -209,11 +212,11 @@ namespace
                   GtkTreeIter       * iter,
                   gpointer            )
   {
-    Log::Entry* log_entry(0);
+    Log::Entry* log_entry(nullptr);
     gtk_tree_model_get (model, iter, COL_MESSAGE, &log_entry, -1);
     bool bold (log_entry->is_child);
     g_object_set (renderer,
-                  "text", log_entry ? log_entry->message.c_str() : "",
+                  "text", log_entry->message.c_str(),
                   "weight", bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
                   NULL);
   }
@@ -222,7 +225,7 @@ namespace
 }
 
 gboolean
-pan :: on_button_pressed (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
+on_button_pressed (GtkWidget *treeview, GdkEventButton *event, gpointer userdata)
 {
   // single click with the right mouse button?
   if (event->type == GDK_BUTTON_PRESS && event->button == 3)
@@ -251,7 +254,7 @@ pan :: on_button_pressed (GtkWidget *treeview, GdkEventButton *event, gpointer u
 }
 
 GtkWidget*
-pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
+log_dialog_new (Prefs& prefs, GtkWindow* window)
 {
   GtkWidget * dialog = gtk_dialog_new_with_buttons (_("Pan: Events"),
                                                     window,
@@ -274,7 +277,7 @@ pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
   gtk_tree_view_set_show_expanders(GTK_TREE_VIEW(view),false);
 
   g_object_set_data_full (G_OBJECT(view), "listener", new MyLogListener(store), delete_my_log_listener);
-  GtkWidget * scroll = gtk_scrolled_window_new (0, 0);
+  GtkWidget * scroll = gtk_scrolled_window_new (nullptr, nullptr);
   gtk_container_set_border_width (GTK_CONTAINER(scroll), PAD_BIG);
   gtk_container_add (GTK_CONTAINER(scroll), view);
 
@@ -294,7 +297,7 @@ pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
   gtk_tree_view_column_set_fixed_width (col, 35);
   gtk_tree_view_column_set_resizable (col, false);
   gtk_tree_view_column_pack_start (col, pixbuf_renderer, false);
-  gtk_tree_view_column_set_cell_data_func (col, pixbuf_renderer, render_severity, dialog, 0);
+  gtk_tree_view_column_set_cell_data_func (col, pixbuf_renderer, render_severity, dialog, nullptr);
   gtk_tree_view_column_set_sort_column_id (col, COL_SEVERITY);
   gtk_tree_view_append_column (GTK_TREE_VIEW(view), col);
 
@@ -304,7 +307,7 @@ pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
   gtk_tree_view_column_set_sort_column_id (col, COL_DATE);
   gtk_tree_view_column_set_title (col, _("Date"));
   gtk_tree_view_column_pack_start (col, text_renderer, false);
-  gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_date, 0, 0);
+  gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_date, nullptr, nullptr);
   gtk_tree_view_append_column (GTK_TREE_VIEW(view), col);
 
   // message
@@ -314,7 +317,7 @@ pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
   gtk_tree_view_column_set_sort_column_id (col, COL_MESSAGE);
   gtk_tree_view_column_set_title (col, _("Message"));
   gtk_tree_view_column_pack_start (col, text_renderer, true);
-  gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_message, 0, 0);
+  gtk_tree_view_column_set_cell_data_func (col, text_renderer, render_message, nullptr, nullptr);
   gtk_tree_view_append_column (GTK_TREE_VIEW(view), col);
   gtk_tree_view_set_expander_column(GTK_TREE_VIEW(view), col);
 
@@ -325,10 +328,12 @@ pan :: log_dialog_new (Prefs& prefs, GtkWindow* window)
   gtk_window_set_role (GTK_WINDOW(dialog), "pan-events-dialog");
   prefs.set_window ("events-window", GTK_WINDOW(dialog), 150, 150, 600, 300);
   gtk_window_set_resizable (GTK_WINDOW(dialog), true);
-  if (window != 0)
+  if (window != nullptr)
     gtk_window_set_transient_for (GTK_WINDOW(dialog), window);
 
   g_signal_connect (view, "button-press-event", G_CALLBACK(on_button_pressed), view);
 
   return dialog;
 }
+
+}
