@@ -481,9 +481,9 @@ ScoreAddDialog :: response_cb (GtkDialog * w, int response, gpointer dialog_gpoi
         _("Another rule already sets this article's score."),
         _("You may want to go back or delete the old rule."));
       gtk_dialog_add_buttons (GTK_DIALOG(d),
-        GTK_STOCK_GO_BACK, -20,
-        GTK_STOCK_DELETE, -21,
-        GTK_STOCK_ADD, -22,
+                              _("Back"), -20,
+                              _("Delete"), -21,
+                              _("Add"), -22,
         NULL);
       const int conflict_response (gtk_dialog_run (GTK_DIALOG(d)));
       gtk_widget_destroy (d);
@@ -553,18 +553,16 @@ namespace
     GtkWidget * label = gtk_label_new_with_mnemonic (_("Add and Re_score"));
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
 
-    GtkWidget * image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
-    GtkWidget * image2 = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
+    GtkWidget * image = gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
+    GtkWidget * image2 = gtk_image_new_from_icon_name ("view-refresh", GTK_ICON_SIZE_BUTTON);
     GtkWidget * hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-    GtkWidget * align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 
     gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), image2, FALSE, FALSE, 0);
     gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    gtk_container_add (GTK_CONTAINER (align), hbox);
-    gtk_container_add (GTK_CONTAINER (button), align);
-    gtk_widget_show_all (align);
+    gtk_container_add (GTK_CONTAINER (button), hbox);
+    gtk_widget_show_all (hbox);
 
     return button;
   }
@@ -605,8 +603,8 @@ ScoreAddDialog :: ScoreAddDialog (Data           & data,
   GtkWidget * w = _root = gtk_dialog_new_with_buttons (s.c_str(),
     GTK_WINDOW(gtk_widget_get_toplevel(parent)),
     GTK_DIALOG_DESTROY_WITH_PARENT,
-    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-    GTK_STOCK_ADD, GTK_RESPONSE_OK,
+    _("Cancel"), GTK_RESPONSE_CANCEL,
+    _("Add"), GTK_RESPONSE_OK,
     NULL);
   g_object_set_data_full (G_OBJECT(w), "dialog", this, delete_score_add_dialog);
   GtkWidget * button = create_rescore_button ();
@@ -622,45 +620,45 @@ ScoreAddDialog :: ScoreAddDialog (Data           & data,
   GtkWidget * t = HIG :: workarea_create ();
   gtk_box_pack_start (GTK_BOX( gtk_dialog_get_content_area( GTK_DIALOG(_root))), t, true, true, 0);
   HIG::workarea_add_section_title (t, &row, _("New Scoring Rule"));
-    HIG::workarea_add_section_spacer (t, row, 4);
+  HIG::workarea_add_section_spacer (t, row, 4);
 
-    // section
-    GtkWidget * h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
-    GtkTreeModel * model = text_tree_model_new (false);
-    w = _section_menu = value_combo_new (model);
-    g_object_unref (G_OBJECT(model));
-    gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
-    w = _section_entry = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    HIG::workarea_add_row (t, &row, _("Group name"), h);
-    gtk_widget_show_all (h);
+  // section
+  GtkWidget * h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+  GtkTreeModel * model = text_tree_model_new (false);
+  w = _section_menu = value_combo_new (model);
+  g_object_unref (G_OBJECT(model));
+  gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
+  w = _section_entry = gtk_entry_new ();
+  gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
+  HIG::workarea_add_row (t, &row, _("Group name"), h);
+  gtk_widget_show_all (h);
 
-    // criteria
-    w = criteria_line_new (_field_menu, _criteria_menu,
-                           _text_criteria_entry, _numeric_criteria_spin,
-                           &_article);
-    HIG::workarea_add_row (t, &row, _("and"), w);
-    gtk_widget_show (w);
+  // criteria
+  w = criteria_line_new (_field_menu, _criteria_menu,
+                         _text_criteria_entry, _numeric_criteria_spin,
+                         &_article);
+  HIG::workarea_add_row (t, &row, _("and"), w);
+  gtk_widget_show (w);
 
-    // score
-    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
-    model = score_tree_model_new ();
-    w = _score_menu = value_combo_new (model);
-    g_object_unref (model);
-    gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    GtkAdjustment * a = (GtkAdjustment*)gtk_adjustment_new (100, INT_MIN, INT_MAX, 1.0, 1.0, 0.0);
-    w = _score_spin = gtk_spin_button_new (a, 100.0, 0u);
-    gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    HIG::workarea_add_wide_control (t, &row, h);
-    gtk_widget_show_all (h);
-    g_signal_connect (_score_menu, "changed", G_CALLBACK(score_combo_changed_cb), w);
+  // score
+  h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+  model = score_tree_model_new ();
+  w = _score_menu = value_combo_new (model);
+  g_object_unref (model);
+  gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
+  GtkAdjustment * a = (GtkAdjustment*)gtk_adjustment_new (100, INT_MIN, INT_MAX, 1.0, 1.0, 0.0);
+  w = _score_spin = gtk_spin_button_new (a, 100.0, 0u);
+  gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
+  HIG::workarea_add_wide_control (t, &row, h);
+  gtk_widget_show_all (h);
+  g_signal_connect (_score_menu, "changed", G_CALLBACK(score_combo_changed_cb), w);
 
-    // duration
-    model = time_tree_model_new ();
-    w = _duration_menu = value_combo_new (model);
-    g_object_unref (model);
-    HIG::workarea_add_wide_control (t, &row, w);
-    gtk_widget_show (w);
+  // duration
+  model = time_tree_model_new ();
+  w = _duration_menu = value_combo_new (model);
+  g_object_unref (model);
+  HIG::workarea_add_wide_control (t, &row, w);
+  gtk_widget_show (w);
 
   populate (group, article, mode);
   gtk_widget_show (t);
