@@ -47,6 +47,9 @@
   #include <libsecret/secret.h>
   #include <gcr/gcr.h>
   #undef GCR_API_SUBJECT_TO_CHANGE
+  #define USE_LIBSECRET_DEFAULT true
+#else
+  #define USE_LIBSECRET_DEFAULT false
 #endif
 
 #include <pan/general/null.h>
@@ -158,7 +161,13 @@ namespace
     gchar* pass(NULL);
     if (!server.empty()) {
       d->data.get_server_addr (server, addr, port);
-      d->data.get_server_auth (server, user, pass, prefs.get_flag("use-password-storage",false));
+      d->data.get_server_auth (
+              server,
+              user,
+              pass,
+              prefs.get_flag(
+                  "use-password-storage",
+                  USE_LIBSECRET_DEFAULT));
       age = d->data.get_server_article_expiration_age (server);
       rank = d->data.get_server_rank (server);
       max_conn = d->data.get_server_limits (server);
@@ -296,7 +305,13 @@ namespace
         if (d->server.empty())
           d->server = d->data.add_new_server ();
         d->data.set_server_addr (d->server, addr, port);
-        d->data.set_server_auth (d->server, user, pass, d->prefs.get_flag("use-password-storage",false));
+        d->data.set_server_auth (
+                d->server,
+                user,
+                pass,
+                d->prefs.get_flag(
+                    "use-password-storage",
+                    USE_LIBSECRET_DEFAULT));
         d->data.set_server_limits (d->server, max_conn);
         d->data.set_server_article_expiration_age (d->server, age);
         d->data.set_server_rank (d->server, rank);
