@@ -24,15 +24,17 @@ class MyListener:
     int new_index_of_moved;
 
   public:
-    virtual void on_set_items_added (AdaptableSet<X, MyLessThan<X> >&, std::vector<X>& i, int index) {
+    void on_set_items_added (AdaptableSet<X, MyLessThan<X> >&, std::vector<X>& i, int index) override
+    {
       index_of_added = index;
       value = i[0];
     }
-    virtual void on_set_item_removed (AdaptableSet<X, MyLessThan<X> >&, X& i, int index) {
+    void on_set_item_removed (AdaptableSet<X, MyLessThan<X> >&, X& i, int index) override {
       index_of_removed = index;
       value = i;
     }
-    virtual void on_set_item_moved (AdaptableSet<X, MyLessThan<X> >&, X& i, int index, int old_index) {
+    void on_set_item_moved (AdaptableSet<X, MyLessThan<X> >&, X& i, int index, int old_index) override
+    {
       old_index_of_moved = old_index;
       new_index_of_moved = index;
       value = i;
@@ -40,7 +42,7 @@ class MyListener:
     void clear () {
       index_of_added = index_of_removed = old_index_of_moved = new_index_of_moved = -1;
     }
-    MyListener () {
+    MyListener () : value() {
       clear ();
     }
     bool empty () const {
@@ -317,6 +319,6 @@ int main ()
   check (m[12] == 20)
   check (m[13] == 25)
   check (m[14] == 30)
- 
+
   return 0;
 }
