@@ -21,6 +21,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
+#include "decoder.h"
+
 #include <config.h>
 #include <cerrno>
 #include <ostream>
@@ -33,14 +35,21 @@
 #include <pan/general/file-util.h>
 #include <pan/general/macros.h>
 #include <pan/general/utf8-utils.h>
-#include "decoder.h"
 
-using namespace pan;
+#include <pan/general/null.h>
+
+namespace pan {
 
 Decoder :: Decoder (WorkerPool& pool):
+  mark_read(false),
+  health(OK),
+  task(nullptr),
+  save_mode(TaskArticle::NONE),
+  options(TaskArticle::SAVE_AS),
+  percent(0.0),
+  num_scanned_files(0),
   _worker_pool (pool),
-  _gsourceid (-1),
-  health(OK)
+  _gsourceid (-1)
 {
 }
 
@@ -100,7 +109,7 @@ Decoder :: do_work()
     {
       if (was_cancelled()) break; // poll WorkerPool::Worker stop flag
 
-      gchar * contents (0);
+      gchar * contents (nullptr);
       gsize length (0);
       if (g_file_get_contents (it->c_str(), &contents, &length, NULL) && length>0)
       {
@@ -154,7 +163,7 @@ Decoder :: do_work()
         if (options == TaskArticle::SAVE_ALL && !article_subject.empty()) {
           global_subject = article_subject.c_str();
         }
-        if ((res = UULoadFileWithPartNo (const_cast<char*>(it->c_str()), 0, 0, ++i, global_subject)) != UURET_OK) {
+        if ((res = UULoadFileWithPartNo (const_cast<char*>(it->c_str()), nullptr, 0, ++i, global_subject)) != UURET_OK) {
           g_snprintf(buf, bufsz,
                      _("Error reading from %s: %s"),
                      it->c_str(),
@@ -239,7 +248,7 @@ void
 Decoder :: uu_log (void* data, char* message, int severity)
 {
   Decoder *self = static_cast<Decoder *>(data);
-  char * pch (g_locale_to_utf8 (message, -1, 0, 0, 0));
+  char * pch (g_locale_to_utf8 (message, -1, nullptr, nullptr, nullptr));
 
   if (severity >= UUMSG_WARNING)
     self->file_errors.push_back (pch ? pch : message);
@@ -340,3 +349,5 @@ Decoder :: disable_progress_update ()
     _gsourceid = -1;
   }
 }
+
+}
